const fs = require('fs');
const path = require('path');
const { service } = require('./src/util/service-layer');

const config = service.configuration;

const production = config.bind.database;

if (process.env.NODE_ENV === 'production' && production.client === 'sqlite3') {
  const directory = path.dirname(production.connection.filename);
  var dir = directory.replace(/\/$/, '').split('/');
  for (let i = 1; i <= dir.length; i++) {
    let segment = dir.slice(0, i).join('/');
    segment.length > 0 && !fs.existsSync(segment)
      ? fs.mkdirSync(segment)
      : null;
  }
}

module.exports = {
  development: {
    client: 'sqlite3',
    connection: {
      filename: './dev.sqlite3',
    },
    seeds: {
      directory: './db/seeds',
    },
    migrations: {
      directory: './db/migrations',
    },
    useNullAsDefault: true,
  },
  production: Object.assign(
    {
      seeds: {
        directory: './db/seeds',
      },
      migrations: {
        directory: './db/migrations',
      },
      useNullAsDefault: true,
    },
    production
  ),
  test: {
    client: 'sqlite3',
    connection: {
      filename: './test.sqlite3',
    },
    migrations: {
      directory: './db/migrations',
    },
    seeds: {
      directory: './db/test_seeds',
    },
    useNullAsDefault: true,
  },
};
