"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var fs_1 = __importDefault(require("fs"));
var path_1 = __importDefault(require("path"));
var ServiceConfiguration = /** @class */ (function () {
    function ServiceConfiguration() {
    }
    /**
     * Select default path for service configuraiton path in different environment
     * By default Backtrace expect to run service from root service directory
     * by using npm commands. In environment different than production
     * @ServiceConfiguration class will read configuration file from root dir.
     * Otherwise from default Backtrace configuration directory
     */
    ServiceConfiguration.prototype.getProjectSettingsPath = function (serviceName) {
        switch (process.env.NODE_ENV) {
            case 'production':
                return "/etc/backtrace/" + serviceName + "/" + serviceName + ".conf";
            default:
                return path_1.default.join(process.cwd(), serviceName + ".conf");
        }
    };
    /**
     * Loads service configuration file
     */
    ServiceConfiguration.prototype.loadConfiguration = function (configurationPath) {
        if (!configurationPath) {
            throw new Error("configurationPath is undefined");
        }
        var config = JSON.parse(fs_1.default.readFileSync(configurationPath, 'utf8'));
        config.isProduction = process.env.NODE_ENV === 'production';
        if (config.ssl) {
            if (config.ssl.key) {
                config.ssl.key = fs_1.default.readFileSync(config.ssl.key);
            }
            if (config.ssl.cert) {
                config.ssl.cert = fs_1.default.readFileSync(config.ssl.cert);
            }
        }
        return config;
    };
    return ServiceConfiguration;
}());
exports.ServiceConfiguration = ServiceConfiguration;
//# sourceMappingURL=serviceConfiguration.js.map