const express = require('express');
const { getConfig, createInstance } = require('./passport');
const Passports = require('./util/passpack');
const session = require('express-session');
const fileStore = require('session-file-store')(session);
const cookieParser = require('cookie-parser');
const { BacktraceService } = require('backtrace-service');
const { service } = require('./util/service-layer');
const { authenticateCoronerd } = require('./util/coronerdTokenCache');

const config = service.configuration;

const PATH_PREFIX = config.pathPrefix;

// exportable function for creating express app to be executed in src/index.js
// allows us to export entire express app for integration testing :)
module.exports = () => {
  const passports = new Passports({
    getConfig,
    createInstance,
  });

  const app = service.app;

  BacktraceService.setupAuth(app);

  BacktraceService.setupMiddlewares(app);

  BacktraceService.setupServiceLayer(app, service.name, service.port, url => {
    service._logger.info(`Service heard from coronerd at ${url}`);
    authenticateCoronerd(url);
  });

  app.set('view engine', 'ejs');

  app.set('views', __dirname + '/views');

  app.use(express.static(__dirname + '/public'));

  app.use(cookieParser());

  app.use(
    session({
      secret: 'Doing it for the lulz',
      store: new fileStore({
        ttl: 10800,
        secret: 'hacktracelol',
      }),
      resave: false,
      saveUninitialized: true,
    })
  );

  // redundant routes for legacy will eventually be able to get rid of this
  app.use('/', require('./routes')(passports));

  // service layer prefixes routes
  app.use(PATH_PREFIX, require('./routes')(passports));

  return app;
};
