const knex = require('knex');
const db = require('../db');
const {
  setTenantCache,
  getTenantCache,
  deleteTenantCache,
} = require('../util/tenantCache');

const Tenant = {};

Tenant.get = hostname => {
  const cachedTenant = getTenantCache(hostname);
  if (cachedTenant && typeof cachedTenant === 'object') {
    return new Promise(function(resolve) {
      resolve([cachedTenant]);
    });
  } else {
    return db('tenants')
      .select('*')
      .where({ hostname })
      .then(data => {
        if (data[0] && data[0].hostname) {
          setTenantCache(Object.assign({}, data[0]));
        }
        return data;
      });
  }
};

Tenant.create = tenant => {
  return db('tenants')
    .insert(tenant)
    .then(() => Tenant.get(tenant.hostname));
};

Tenant.modify = tenant => {
  return db('tenants')
    .where({ hostname: tenant.hostname })
    .update(tenant)
    .then(() => {
      deleteTenantCache(tenant.hostname);
      return Tenant.get(tenant.hostname);
    });
};

Tenant.delete = hostname => {
  deleteTenantCache(hostname);
  return db('tenants')
    .where({ hostname: hostname })
    .del()
    .then(() => {
      return deleteTenantCache(hostname);
    });
};

module.exports = Tenant;
