const router = require('express').Router();
const cors = require('cors');
const { getMetrics } = require('../util/metricsCache');
const getVersion = require('../util/getVersion');
const { service } = require('../util/service-layer');

const APP_VERSION = getVersion();

module.exports = passports => {
  router.use('/', require('./api')(passports));

  // For legacy routing -- should deprecate this as soon as possible...
  router.use('/api/saml', require('./api')(passports));

  router.use('/saml', require('./saml')(passports));

  // Route used by Circonus to retreive success/failure metrics
  router.get('/metrics', getMetrics);

  // Route to get basic config for service
  // Used by console to detect if service exists
  router.get('/config', cors(), (req, res) => {
    const start = Date.now();
    res.json({
      response: { status: 'ok' },
      _: {
        version: APP_VERSION,
        latency: Date.now() - start,
      },
    });
  });

  // Needed for legacy to coordinate with FE
  router.get('/api/config', cors(), (req, res) => {
    const start = Date.now();
    res.json({
      response: { status: 'ok' },
      _: {
        version: APP_VERSION,
        latency: Date.now() - start,
      },
    });
  });

  return router;
};
