const https = require('https');
const axios = require('axios');
const { service } = require('./service-layer');

const httpsAgent = service.identityManager.descr.isOnPremise
  ? new https.Agent({ rejectUnauthorized: false })
  : https.globalAgent;

const actionType = 'configuration/users';

function getBPGUsers(coronerdUrl, token) {
  const prefix = coronerdUrl.endsWith('/') ? '' : '/';
  const requestUrl = `${coronerdUrl}${prefix}api/bpg`;

  const data = {
    actions: [
      {
        action: 'get',
        type: actionType,
      },
    ],
  };

  return axios
    .post(requestUrl, data, {
      httpsAgent,
      headers: {
        'Content-Type': 'application/json',
        'X-Coroner-Token': token,
      },
    })
    .then(({ data }) => {
      return parseBPGResponse(data);
    });
}

function createBPGUsers(coronerdUrl, token, user) {
  const prefix = coronerdUrl.endsWith('/') ? '' : '/';
  const requestUrl = `${coronerdUrl}${prefix}api/bpg`;

  const { username, email, universe } = user;

  const data = {
    actions: [
      {
        action: 'create',
        type: actionType,
        object: {
          universe,
          username,
          email,
          method: 'saml',
          role: 'member',
          superuser: 0,
        },
      },
    ],
  };

  return axios
    .post(requestUrl, data, {
      httpsAgent,
      headers: {
        'Content-Type': 'application/json',
        'X-Coroner-Token': token,
      },
    })
    .then(({ data }) => {
      return parseBPGResponse(data);
    });
}

function getActionIndex(response) {
  let index = 0;
  const { actions } = response;
  for (let i = 0; i < actions.length; i++) {
    if (actions[i].type === actionType) {
      index = i;
      break;
    }
  }
  return index;
}

function parseBPGResponse(response) {
  const actionIndex = getActionIndex(response);
  const actionResult = response.results[actionIndex];

  if (actionResult.text !== 'success') {
    throw new Error(actionResult.text);
  }

  return actionResult.result;
}

function getUniqueUsername(users, email) {
  const baseUsername = email.split('@')[0];
  let username = baseUsername;
  let iterateUsername = true;
  let i = 1;
  while (iterateUsername) {
    let idx = users.findIndex(user => user.username == username);
    if (idx === -1) {
      iterateUsername = false;
    } else {
      username = baseUsername + i;
      i++;
    }
  }

  return username;
}

module.exports = {
  getBPGUsers,
  createBPGUsers,
  getUniqueUsername,
};
